@@ -23,8 +23,7 @@ from sys import stderr
 from time import sleep
 from typing import Iterable
 
-from palace import (reverb_preset_names, decode,
-                    Device, Context, Source, AuxiliaryEffectSlot, Effect)
+from palace import reverb_preset_names, decode, Device, Context, Source, Effect
 
 CHUNK_LEN: int = 12000
 QUEUE_SIZE: int = 4
@@ -32,6 +31,7 @@ PERIOD: float = 0.025
 
 
 class PresetPrinter(Action):
+    """CLI action to print available preset names and exit."""
     def __call__(self, parser: ArgumentParser, *args, **kwargs) -> None:
         print('Available reverb preset names:', *reverb_preset_names, sep='\n')
         parser.exit()
@@ -48,11 +48,10 @@ def play(files: Iterable[str], device: str, reverb: str) -> None:
     """Load and play files on the given device."""
     with Device(device) as dev, Context(dev) as ctx:
         print('Opened', dev.name)
-        with Source() as src, AuxiliaryEffectSlot() as slot, Effect() as fx:
+        with Source() as src, Effect() as fx:
             print('Loading reverb preset', reverb)
             fx.reverb_preset = reverb
-            slot.effect = fx
-            src.auxiliary_send = slot, 0
+            src.sends[0].effect = fx
 
             for filename in files:
                 try:
